@@ -17,7 +17,7 @@ use Try::Catch;
 use Time::HiRes qw(ualarm);
 
 # Set the package version. 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -116,8 +116,10 @@ sub reset_screen {
 # stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
 #------------------------------------------------------------------------------# 
 sub cursor_on {
-    # Show the cursor.
-    print "${CSI}?25h";
+    # Set the sequence.
+    my $seq = "?25h";
+    # Show the cursor. Send command to the terminal.
+    print "${CSI}${seq}";
 };
 
 #------------------------------------------------------------------------------# 
@@ -128,8 +130,10 @@ sub cursor_on {
 # stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
 #------------------------------------------------------------------------------# 
 sub cursor_off {
-    # Hide the cursor.
-    print "${CSI}?25l";
+    # Set the sequence.
+    my $seq = "?25l";
+    # Hide the cursor. Send command to the terminal.
+    print "${CSI}${seq}";
 };
 
 #------------------------------------------------------------------------------# 
@@ -140,7 +144,7 @@ sub cursor_off {
 # stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
 #------------------------------------------------------------------------------# 
 sub echo_on {
-    # Turn echo on.
+    # Turn echo on. Make use of system call of stty.
     system("stty echo </dev/tty >/dev/tty 2>&1");
 };
 
@@ -152,7 +156,7 @@ sub echo_on {
 # stty for reading from tty and writing to tty. Redirect stderr to stdout.     #
 #------------------------------------------------------------------------------# 
 sub echo_off {
-    # Turn echo off.
+    # Turn echo off. Make use of system call of stty.
     system("stty -echo </dev/tty >/dev/tty 2>&1");
 };
 
@@ -256,9 +260,9 @@ sub window_size_pixels {
     # Set the timeout.
     my $timeout = $_[0];
     # Get width and height.
-    my ($x, $y) = ctlseqs_request("14", $timeout);
-    # Return width and height.
-    return ($x, $y);
+    my ($width, $height) = ctlseqs_request("14", $timeout);
+    # Return height and width.
+    return ($height, $width);
 };
 
 #------------------------------------------------------------------------------# 
@@ -274,9 +278,9 @@ sub screen_size_pixels {
     # Set the timeout.
     my $timeout = $_[0];
     # Get width and height.
-    my ($x, $y) = ctlseqs_request("15", $timeout);
-    # Return width and height.
-    return ($x, $y);
+    my ($width, $height) = ctlseqs_request("15", $timeout);
+    # Return height and width.
+    return ($height, $width);
 };
 
 #------------------------------------------------------------------------------# 
@@ -286,15 +290,15 @@ sub screen_size_pixels {
 # Xterm Control Sequences                                                      #
 # Request: CSI Ps t                                                            #
 # Response: Ps = 18 -> Reports xterm window size in chars as                   #
-#                      CSI 8 ; width ; height t                                #
+#                      CSI 8 ; height ; width t                                #
 #------------------------------------------------------------------------------# 
 sub window_size_chars {
     # Set the timeout.
     my $timeout = $_[0];
-    # Get width and height.
-    my ($x, $y) = ctlseqs_request("18", $timeout);
-    # Return width and height.
-    return ($x, $y);
+    # Get height and width.
+    my ($height, $width) = ctlseqs_request("18", $timeout);
+    # Return height and width.
+    return ($height, $width);
 };
 
 #------------------------------------------------------------------------------# 
@@ -304,14 +308,14 @@ sub window_size_chars {
 # Xterm Control Sequences                                                      #
 # Request: CSI Ps t                                                            #
 # Response: Ps = 19 -> Reports xterm window size in chars as                   #
-#                      CSI 9 ; width ; height t                                #
+#                      CSI 9 ; height ; width t                                #
 #------------------------------------------------------------------------------# 
 sub screen_size_chars {
     # Set the timeout.
     my $timeout = $_[0];
-    # Get width and height.
+    # Get height and width.
     my ($height, $width) = ctlseqs_request("19", $timeout);
-    # Return width and height.
+    # Return height and width.
     return ($height, $width);
 };
 
@@ -431,54 +435,81 @@ Terminal::Control - Perl extension for the terminal window control
 
   use Terminal::Control;
 
-  # Clear screen.
+  # Clear screen using escape sequences.
   clear_screen();
 
-  # Reset screen.
+  # Reset screen using escape sequences.
   reset_screen();
 
-  # Get terminal size and print to screen.
+  # Get terminal size calling ioctl and output the result on the screen.
   my ($rows, $cols, $xpix, $ypix) = winsize();
   printf ("%s\n%s\n%s\n%s\n", $rows, $cols, $xpix, $ypix);
 
-  # Get chars and print to screen.
+  # Get chars from terminal size and output the result on the screen.
   ($rows, $cols) = chars();
+  # Print chars.
   printf ("%s\n%s\n", $rows, $cols);
 
-  # Get pixels and print to screen. 
+  # Get pixels from terminal size and output the result on the screen.
   ($xpix, $ypix) = pixels();
   printf ("%s\n%s\n", $xpix, $ypix);
 
-  # Get cursor position.
+  # Get the cursor position using escape sequences.
   my ($y, $x) = get_cursor_position();
   printf ("%s\n%s\n", $y, $x);
 
-  # Set cursor position.
+  # Set the cursor position using escape sequences.
   my $y = 20; 
   my $x = 80; 
   set_cursor_position($y, $x);
 
-=head1 Requirement
+  # Enable echo of commands using stty. 
+  echo_on();
 
-The Perl header 'sys/ioctl.ph' is required for the ioctl call of the function
-TIOCGWINSZ. The equivalent C/C++ header is 'sys/ioctl.h'. The Perl command h2ph
-converts '.h' C/C++ header files to '.ph' Perl header files.
+  # Disable echo of commands using stty. 
+  echo_off();
+
+  # Enable cursor using escape sequences.
+  cursor_on();
+
+  # Disable cursor using escape sequences.
+  cursor_off();
+
+  # Set timeout in microseconds.
+  my $timeout = 1000000;
+  # Get window and screen size using escape sequences.
+  window_size_chars($timeout);
+  windows_size_pixels($timeout);
+  screen_size_chars($timeout);
+  screen_size_pixels($timeout);
+
+=head1 Requirement for Full Functionality
+
+The Perl header C<sys/ioctl.ph> is required for the C<ioctl> call of the
+function C<TIOCGWINSZ> to get the window size. The equivalent C/C++ header
+is C<sys/ioctl.h>. The Perl command C<h2ph> converts C<.h> C/C++ header files to
+C<.ph> Perl header files.
 
 In contrast to modules in general, the module installation process cannot be told
-to create a sys/ioctl.ph. This is necessary manually via the h2ph command.
+to create a C<sys/ioctl.ph>. This is necessary manually via the C<h2ph> command.
 
-To prevent tests within CPAN from failing due to a missing sys/ioctl.ph, a fallback
-solution based on the BASH command stty is programmed.   
+To prevent tests within CPAN from failing due to a missing C<sys/ioctl.ph>, a
+fallback solution based on the Shell command C<stty> is implemented.   
+
+=head1 Introduction
+
+The module can be used on Unix-like systems. 
 
 =head1 Motivation
 
 The idea for the necessity of the module arises from the fact that especially 
-the system call system("reset") of the BASH command reset is noticeably slow.
-The BASH command reset is slow, the system call system("reset") is slower. By
-using so-called ASCII escape sequences, a significant acceleration can be
-achieved. The logical consequence is the programming of a Perl command that
-replaces the system call. A simple method is the best way to realise this. There
-is no need to implement a special Class to achive this.  
+the Perl system command call C<system("reset")> of the Shell command C<reset>
+is noticeably slow. The Shell command C<reset> is slow, the Perl system command
+call C<system("reset")> is slower. By using so-called ASCII escape sequences,
+a significant acceleration can be achieved. The logical consequence is the
+programming of a Perl command that replaces the Perl system command call. A
+simple method is the best way to realise this. There is no need to implement a
+special class to achive this.  
 
 =head1 Benchmark
 
@@ -504,7 +535,7 @@ The following methods have been implemented so far:
 
 =item * get_cursor_position()
 
-=item * set_cursor_position()
+=item * set_cursor_position($rows, $cols)
 
 =item * winsize()
 
@@ -520,6 +551,14 @@ The following methods have been implemented so far:
 
 =item * cursor_off()
 
+=item * screen_size_chars($timeout) 
+
+=item * screen_size_pixels($timeout)
+
+=item * window_size_chars($timeout)
+
+=item * windows_size_pixels($timeout)
+
 =back
 
 =head1 Aliases
@@ -533,25 +572,30 @@ clear_screen and reset_screen can also be used with this aliases:
 
 =head2 Method description
 
-The method clear_screen is clearing the terminal. This is similar to the system call system('clear').
-The method reset_screen is reseting the terminal. This is similar to the system call system('reset').
+The method C<clear_screen> is clearing the terminal. This is similar to the
+Perl system command call C<system('clear')>. The method C<reset_screen> is
+reseting the terminal. This is similar to the Perl system command call
+C<system('reset')>.
 
-The method winsize gets the dimensions in x-direction and y-direction of the terminal. The methods chars
-and pixels extract chars (rows and cols) and pixels (xpix and ypix.)
+The method winsize gets the dimensions in x-direction and y-direction
+of the terminal. The methods chars and pixels extract chars (rows and cols)
+ and pixels (xpix and ypix.)
 
-The method get_cursor_position() gets the current cursor position in the terminal window. The method
-set_cursor_position() sets the cursor position in the terminal window.
+The method C<get_cursor_position()> gets the current cursor position in
+the terminal window. The method C<set_cursor_position()> sets the cursor
+position in the terminal window.
  
-echo_on and echo_off turnes echo of commands on or off. cursor_on and cursor_off shows or hides the cursor.
+C<echo_on()> and C<echo_off()> turnes echo of commands on or off. cursor_on and
+cursor_off shows or hides the cursor.
 
 =head1 Programmable background
 
-The methods clear_screen and reset_screen are using escape sequences. Doing this
+The methods C<clear_screen()> and C<reset_screen()> are using escape sequences. Doing this
 no other Perl modules are needed to clear and reset a screen. Both are in principle
 one liners.
 
-The method winsize is using the C/C++ header for the system ioctl call and there
-the command TIOCGWINSZ. The call return winsize in rows and cols and xpix and ypix.
+The method winsize is using the C/C++ header for the system C<ioctl> call and there
+the command C<TIOCGWINSZ>. The call return winsize in rows and cols and xpix and ypix.
 
 =head1 SEE ALSO
 
